# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/secret/v1/secret_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.secret.v1 import secret_pb2 as spaceone_dot_api_dot_secret_dot_v1_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)spaceone/api/secret/v1/secret_group.proto\x12\x16spaceone.api.secret.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a#spaceone/api/secret/v1/secret.proto\"b\n\x18\x43reateSecretGroupRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04tags\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"{\n\x18UpdateSecretGroupRequest\x12\x17\n\x0fsecret_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"@\n\x12SecretGroupRequest\x12\x17\n\x0fsecret_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"Q\n\x15GetSecretGroupRequest\x12\x17\n\x0fsecret_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"Y\n\x18SecretGroupSecretRequest\x12\x17\n\x0fsecret_group_id\x18\x01 \x01(\t\x12\x11\n\tsecret_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"\x8b\x01\n\x10SecretGroupQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x17\n\x0fsecret_group_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tsecret_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"\xa7\x01\n\x15SecretGroupSecretInfo\x12\x42\n\x11secret_group_info\x18\x01 \x01(\x0b\x32\'.spaceone.api.secret.v1.SecretGroupInfo\x12\x37\n\x0bsecret_info\x18\x02 \x01(\x0b\x32\".spaceone.api.secret.v1.SecretInfo\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"\x86\x01\n\x0fSecretGroupInfo\x12\x17\n\x0fsecret_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\"a\n\x10SecretGroupsInfo\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\'.spaceone.api.secret.v1.SecretGroupInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"_\n\x14SecretGroupStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa7\t\n\x0bSecretGroup\x12\x85\x01\n\x06\x63reate\x12\x30.spaceone.api.secret.v1.CreateSecretGroupRequest\x1a\'.spaceone.api.secret.v1.SecretGroupInfo\" \x82\xd3\xe4\x93\x02\x1a\"\x18/secret/v1/secret-groups\x12\x96\x01\n\x06update\x12\x30.spaceone.api.secret.v1.UpdateSecretGroupRequest\x1a\'.spaceone.api.secret.v1.SecretGroupInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/secret/v1/secret-group/{secret_group_id}\x12\xa8\x01\n\nadd_secret\x12\x30.spaceone.api.secret.v1.SecretGroupSecretRequest\x1a-.spaceone.api.secret.v1.SecretGroupSecretInfo\"9\x82\xd3\xe4\x93\x02\x33\"1/secret/v1/secret-group/{secret_group_id}/secrets\x12\x9f\x01\n\rremove_secret\x12\x30.spaceone.api.secret.v1.SecretGroupSecretRequest\x1a\x16.google.protobuf.Empty\"D\x82\xd3\xe4\x93\x02>*</secret/v1/secret-group/{secret_group_id}/secret/{secret_id}\x12\x7f\n\x06\x64\x65lete\x12*.spaceone.api.secret.v1.SecretGroupRequest\x1a\x16.google.protobuf.Empty\"1\x82\xd3\xe4\x93\x02+*)/secret/v1/secret-group/{secret_group_id}\x12\x90\x01\n\x03get\x12-.spaceone.api.secret.v1.GetSecretGroupRequest\x1a\'.spaceone.api.secret.v1.SecretGroupInfo\"1\x82\xd3\xe4\x93\x02+\x12)/secret/v1/secret-group/{secret_group_id}\x12\x9f\x01\n\x04list\x12(.spaceone.api.secret.v1.SecretGroupQuery\x1a(.spaceone.api.secret.v1.SecretGroupsInfo\"C\x82\xd3\xe4\x93\x02=\x12\x18/secret/v1/secret-groupsZ!\"\x1f/secret/v1/secret-groups/search\x12t\n\x04stat\x12,.spaceone.api.secret.v1.SecretGroupStatQuery\x1a\x17.google.protobuf.Struct\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/secret/v1/secret-groups/statb\x06proto3')



_CREATESECRETGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateSecretGroupRequest']
_UPDATESECRETGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateSecretGroupRequest']
_SECRETGROUPREQUEST = DESCRIPTOR.message_types_by_name['SecretGroupRequest']
_GETSECRETGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetSecretGroupRequest']
_SECRETGROUPSECRETREQUEST = DESCRIPTOR.message_types_by_name['SecretGroupSecretRequest']
_SECRETGROUPQUERY = DESCRIPTOR.message_types_by_name['SecretGroupQuery']
_SECRETGROUPSECRETINFO = DESCRIPTOR.message_types_by_name['SecretGroupSecretInfo']
_SECRETGROUPINFO = DESCRIPTOR.message_types_by_name['SecretGroupInfo']
_SECRETGROUPSINFO = DESCRIPTOR.message_types_by_name['SecretGroupsInfo']
_SECRETGROUPSTATQUERY = DESCRIPTOR.message_types_by_name['SecretGroupStatQuery']
CreateSecretGroupRequest = _reflection.GeneratedProtocolMessageType('CreateSecretGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESECRETGROUPREQUEST,
  '__module__' : 'spaceone.api.secret.v1.secret_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.CreateSecretGroupRequest)
  })
_sym_db.RegisterMessage(CreateSecretGroupRequest)

UpdateSecretGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateSecretGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESECRETGROUPREQUEST,
  '__module__' : 'spaceone.api.secret.v1.secret_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.UpdateSecretGroupRequest)
  })
_sym_db.RegisterMessage(UpdateSecretGroupRequest)

SecretGroupRequest = _reflection.GeneratedProtocolMessageType('SecretGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETGROUPREQUEST,
  '__module__' : 'spaceone.api.secret.v1.secret_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretGroupRequest)
  })
_sym_db.RegisterMessage(SecretGroupRequest)

GetSecretGroupRequest = _reflection.GeneratedProtocolMessageType('GetSecretGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSECRETGROUPREQUEST,
  '__module__' : 'spaceone.api.secret.v1.secret_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.GetSecretGroupRequest)
  })
_sym_db.RegisterMessage(GetSecretGroupRequest)

SecretGroupSecretRequest = _reflection.GeneratedProtocolMessageType('SecretGroupSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETGROUPSECRETREQUEST,
  '__module__' : 'spaceone.api.secret.v1.secret_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretGroupSecretRequest)
  })
_sym_db.RegisterMessage(SecretGroupSecretRequest)

SecretGroupQuery = _reflection.GeneratedProtocolMessageType('SecretGroupQuery', (_message.Message,), {
  'DESCRIPTOR' : _SECRETGROUPQUERY,
  '__module__' : 'spaceone.api.secret.v1.secret_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretGroupQuery)
  })
_sym_db.RegisterMessage(SecretGroupQuery)

SecretGroupSecretInfo = _reflection.GeneratedProtocolMessageType('SecretGroupSecretInfo', (_message.Message,), {
  'DESCRIPTOR' : _SECRETGROUPSECRETINFO,
  '__module__' : 'spaceone.api.secret.v1.secret_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretGroupSecretInfo)
  })
_sym_db.RegisterMessage(SecretGroupSecretInfo)

SecretGroupInfo = _reflection.GeneratedProtocolMessageType('SecretGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _SECRETGROUPINFO,
  '__module__' : 'spaceone.api.secret.v1.secret_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretGroupInfo)
  })
_sym_db.RegisterMessage(SecretGroupInfo)

SecretGroupsInfo = _reflection.GeneratedProtocolMessageType('SecretGroupsInfo', (_message.Message,), {
  'DESCRIPTOR' : _SECRETGROUPSINFO,
  '__module__' : 'spaceone.api.secret.v1.secret_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretGroupsInfo)
  })
_sym_db.RegisterMessage(SecretGroupsInfo)

SecretGroupStatQuery = _reflection.GeneratedProtocolMessageType('SecretGroupStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SECRETGROUPSTATQUERY,
  '__module__' : 'spaceone.api.secret.v1.secret_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.secret.v1.SecretGroupStatQuery)
  })
_sym_db.RegisterMessage(SecretGroupStatQuery)

_SECRETGROUP = DESCRIPTOR.services_by_name['SecretGroup']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SECRETGROUP.methods_by_name['create']._options = None
  _SECRETGROUP.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\032\"\030/secret/v1/secret-groups'
  _SECRETGROUP.methods_by_name['update']._options = None
  _SECRETGROUP.methods_by_name['update']._serialized_options = b'\202\323\344\223\002+\032)/secret/v1/secret-group/{secret_group_id}'
  _SECRETGROUP.methods_by_name['add_secret']._options = None
  _SECRETGROUP.methods_by_name['add_secret']._serialized_options = b'\202\323\344\223\0023\"1/secret/v1/secret-group/{secret_group_id}/secrets'
  _SECRETGROUP.methods_by_name['remove_secret']._options = None
  _SECRETGROUP.methods_by_name['remove_secret']._serialized_options = b'\202\323\344\223\002>*</secret/v1/secret-group/{secret_group_id}/secret/{secret_id}'
  _SECRETGROUP.methods_by_name['delete']._options = None
  _SECRETGROUP.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002+*)/secret/v1/secret-group/{secret_group_id}'
  _SECRETGROUP.methods_by_name['get']._options = None
  _SECRETGROUP.methods_by_name['get']._serialized_options = b'\202\323\344\223\002+\022)/secret/v1/secret-group/{secret_group_id}'
  _SECRETGROUP.methods_by_name['list']._options = None
  _SECRETGROUP.methods_by_name['list']._serialized_options = b'\202\323\344\223\002=\022\030/secret/v1/secret-groupsZ!\"\037/secret/v1/secret-groups/search'
  _SECRETGROUP.methods_by_name['stat']._options = None
  _SECRETGROUP.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\037\"\035/secret/v1/secret-groups/stat'
  _CREATESECRETGROUPREQUEST._serialized_start=229
  _CREATESECRETGROUPREQUEST._serialized_end=327
  _UPDATESECRETGROUPREQUEST._serialized_start=329
  _UPDATESECRETGROUPREQUEST._serialized_end=452
  _SECRETGROUPREQUEST._serialized_start=454
  _SECRETGROUPREQUEST._serialized_end=518
  _GETSECRETGROUPREQUEST._serialized_start=520
  _GETSECRETGROUPREQUEST._serialized_end=601
  _SECRETGROUPSECRETREQUEST._serialized_start=603
  _SECRETGROUPSECRETREQUEST._serialized_end=692
  _SECRETGROUPQUERY._serialized_start=695
  _SECRETGROUPQUERY._serialized_end=834
  _SECRETGROUPSECRETINFO._serialized_start=837
  _SECRETGROUPSECRETINFO._serialized_end=1004
  _SECRETGROUPINFO._serialized_start=1007
  _SECRETGROUPINFO._serialized_end=1141
  _SECRETGROUPSINFO._serialized_start=1143
  _SECRETGROUPSINFO._serialized_end=1240
  _SECRETGROUPSTATQUERY._serialized_start=1242
  _SECRETGROUPSTATQUERY._serialized_end=1337
  _SECRETGROUP._serialized_start=1340
  _SECRETGROUP._serialized_end=2531
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/provisioning/v1/resource.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a spaceone/api/core/v1/query.proto\"\x83\x02\n\rResourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12\x11\n\tdomain_id\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x15\n\rresource_type\x18\n \x01(\t\"\x81\x04\n\x15\x43reateResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11resource_group_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\x16\n\x0eterraform_code\x18\x05 \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x0f\n\x07img_src\x18\n \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x12\n\nupdated_by\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\r \x01(\t\x12\x12\n\nupdated_at\x18\x0e \x01(\t\x12\x12\n\nsort_order\x18\x0f \x01(\x05\x12\x15\n\rresource_type\x18\x10 \x01(\t\x12\x39\n\x18resource_type_properties\x18\x11 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x14terraform_properties\x18\x12 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x33\n\x12\x61nsible_properties\x18\x13 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xee\x03\n\x15UpdateResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x07 \x01(\t\x12\x13\n\x0bvalid_value\x18\x08 \x03(\t\x12\x10\n\x08provider\x18\n \x01(\t\x12\x0f\n\x07img_src\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x0c \x01(\t\x12\x12\n\nupdated_by\x18\r \x01(\t\x12\x12\n\nsort_order\x18\x0e \x01(\x05\x12\x15\n\rresource_type\x18\x0f \x01(\t\x12\x39\n\x18resource_type_properties\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x14terraform_properties\x18\x11 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x33\n\x12\x61nsible_properties\x18\x12 \x01(\x0b\x32\x17.google.protobuf.Struct\"9\n\x0fResourceRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\\\n\x11ResourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x8d\x04\n\x0cResourceInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x0f\n\x07img_src\x18\n \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x12\n\nupdated_by\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\r \x01(\t\x12\x12\n\nupdated_at\x18\x0e \x01(\t\x12\x12\n\nsort_order\x18\x0f \x01(\x05\x12\x14\n\x0c\x61nsible_code\x18\x10 \x01(\t\x12\x15\n\rresource_type\x18\x11 \x01(\t\x12\x39\n\x18resource_type_properties\x18\x12 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x35\n\x14terraform_properties\x18\x13 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x33\n\x12\x61nsible_properties\x18\x14 \x01(\x0b\x32\x17.google.protobuf.Struct\"a\n\rResourcesInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.provisioning.v1.ResourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x96\x07\n\x08Resource\x12\x95\x01\n\x0f\x63reate_resource\x12\x33.spaceone.api.provisioning.v1.CreateResourceRequest\x1a*.spaceone.api.provisioning.v1.ResourceInfo\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/provisioning/v1/resource\x12\xb1\x01\n\rget_resources\x12+.spaceone.api.provisioning.v1.ResourceQuery\x1a+.spaceone.api.provisioning.v1.ResourcesInfo\"F\x82\xd3\xe4\x93\x02@\x12\x1a/provisioning/v1/resourcesZ\"\" /provisioning/v1/resource/search\x12\x9a\x01\n\x0cget_resource\x12-.spaceone.api.provisioning.v1.ResourceRequest\x1a*.spaceone.api.provisioning.v1.ResourceInfo\"/\x82\xd3\xe4\x93\x02)\x12\'/provisioning/v1/resource/{resource_id}\x12\x95\x01\n\x0fupdate_resource\x12\x33.spaceone.api.provisioning.v1.UpdateResourceRequest\x1a*.spaceone.api.provisioning.v1.ResourceInfo\"!\x82\xd3\xe4\x93\x02\x1b\x1a\x19/provisioning/v1/resource\x12\x8e\x01\n\x0f\x64\x65lete_resource\x12-.spaceone.api.provisioning.v1.ResourceRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.*,/provisioning/v1/resource/{resource_request}\x12x\n\x04stat\x12/.spaceone.api.provisioning.v1.ResourceStatQuery\x1a\x17.google.protobuf.Struct\"&\x82\xd3\xe4\x93\x02 \"\x1e/provisioning/v1/resource/statb\x06proto3')



_RESOURCEQUERY = DESCRIPTOR.message_types_by_name['ResourceQuery']
_CREATERESOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateResourceRequest']
_UPDATERESOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateResourceRequest']
_RESOURCEREQUEST = DESCRIPTOR.message_types_by_name['ResourceRequest']
_RESOURCESTATQUERY = DESCRIPTOR.message_types_by_name['ResourceStatQuery']
_RESOURCEINFO = DESCRIPTOR.message_types_by_name['ResourceInfo']
_RESOURCESINFO = DESCRIPTOR.message_types_by_name['ResourcesInfo']
ResourceQuery = _reflection.GeneratedProtocolMessageType('ResourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceQuery)
  })
_sym_db.RegisterMessage(ResourceQuery)

CreateResourceRequest = _reflection.GeneratedProtocolMessageType('CreateResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateResourceRequest)
  })
_sym_db.RegisterMessage(CreateResourceRequest)

UpdateResourceRequest = _reflection.GeneratedProtocolMessageType('UpdateResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateResourceRequest)
  })
_sym_db.RegisterMessage(UpdateResourceRequest)

ResourceRequest = _reflection.GeneratedProtocolMessageType('ResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceRequest)
  })
_sym_db.RegisterMessage(ResourceRequest)

ResourceStatQuery = _reflection.GeneratedProtocolMessageType('ResourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceStatQuery)
  })
_sym_db.RegisterMessage(ResourceStatQuery)

ResourceInfo = _reflection.GeneratedProtocolMessageType('ResourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceInfo)
  })
_sym_db.RegisterMessage(ResourceInfo)

ResourcesInfo = _reflection.GeneratedProtocolMessageType('ResourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourcesInfo)
  })
_sym_db.RegisterMessage(ResourcesInfo)

_RESOURCE = DESCRIPTOR.services_by_name['Resource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCE.methods_by_name['create_resource']._options = None
  _RESOURCE.methods_by_name['create_resource']._serialized_options = b'\202\323\344\223\002\033\"\031/provisioning/v1/resource'
  _RESOURCE.methods_by_name['get_resources']._options = None
  _RESOURCE.methods_by_name['get_resources']._serialized_options = b'\202\323\344\223\002@\022\032/provisioning/v1/resourcesZ\"\" /provisioning/v1/resource/search'
  _RESOURCE.methods_by_name['get_resource']._options = None
  _RESOURCE.methods_by_name['get_resource']._serialized_options = b'\202\323\344\223\002)\022\'/provisioning/v1/resource/{resource_id}'
  _RESOURCE.methods_by_name['update_resource']._options = None
  _RESOURCE.methods_by_name['update_resource']._serialized_options = b'\202\323\344\223\002\033\032\031/provisioning/v1/resource'
  _RESOURCE.methods_by_name['delete_resource']._options = None
  _RESOURCE.methods_by_name['delete_resource']._serialized_options = b'\202\323\344\223\002.*,/provisioning/v1/resource/{resource_request}'
  _RESOURCE.methods_by_name['stat']._options = None
  _RESOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002 \"\036/provisioning/v1/resource/stat'
  _RESOURCEQUERY._serialized_start=201
  _RESOURCEQUERY._serialized_end=460
  _CREATERESOURCEREQUEST._serialized_start=463
  _CREATERESOURCEREQUEST._serialized_end=976
  _UPDATERESOURCEREQUEST._serialized_start=979
  _UPDATERESOURCEREQUEST._serialized_end=1473
  _RESOURCEREQUEST._serialized_start=1475
  _RESOURCEREQUEST._serialized_end=1532
  _RESOURCESTATQUERY._serialized_start=1534
  _RESOURCESTATQUERY._serialized_end=1626
  _RESOURCEINFO._serialized_start=1629
  _RESOURCEINFO._serialized_end=2154
  _RESOURCESINFO._serialized_start=2156
  _RESOURCESINFO._serialized_end=2253
  _RESOURCE._serialized_start=2256
  _RESOURCE._serialized_end=3174
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/stack_temp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-spaceone/api/provisioning/v1/stack_temp.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a spaceone/api/core/v1/query.proto\"\x99\x01\n\x16\x43reateStackTempRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nstack_name\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\"<\n\x10StackTempRequest\x12\x15\n\rstack_temp_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"M\n\x13GetStackTempRequest\x12\x15\n\rstack_temp_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb0\x02\n\x16UpdateStackTempRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x15\n\rstack_temp_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x16\n\x0eterraform_code\x18\x04 \x01(\t\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_at\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12\x1a\n\x12service_account_id\x18\n \x01(\t\x12\x10\n\x08provider\x18\x0b \x01(\t\x12\r\n\x05graph\x18\x0c \x01(\t\x12\x37\n\x06\x65rrors\x18\r \x01(\x0b\x32\'.spaceone.api.provisioning.v1.ErrorInfo\"\xcf\x02\n\rStackTempInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x15\n\rstack_temp_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x16\n\x0eterraform_code\x18\x04 \x01(\t\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x12\n\nupdated_by\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_at\x18\x08 \x01(\t\x12\x0e\n\x06status\x18\t \x01(\t\x12\x12\n\nproject_id\x18\n \x01(\t\x12\x1a\n\x12service_account_id\x18\x0b \x01(\t\x12\x10\n\x08provider\x18\x0c \x01(\t\x12\r\n\x05graph\x18\r \x01(\t\x12\x37\n\x06\x65rrors\x18\x0e \x01(\x0b\x32\'.spaceone.api.provisioning.v1.ErrorInfo\"c\n\x0eStackTempsInfo\x12<\n\x07results\x18\x01 \x03(\x0b\x32+.spaceone.api.provisioning.v1.StackTempInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xb2\x01\n\x0eStackTempQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x15\n\rstack_temp_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x12\n\nupdated_by\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\t\"]\n\tErrorInfo\x12\x12\n\nerror_code\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12+\n\nadditional\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct2\xbf\x06\n\tStackTemp\x12\x9b\x01\n\x11\x63reate_stack_temp\x12\x34.spaceone.api.provisioning.v1.CreateStackTempRequest\x1a+.spaceone.api.provisioning.v1.StackTempInfo\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/provisioning/v1/stack_temp\x12\xba\x01\n\x0fget_stack_temps\x12,.spaceone.api.provisioning.v1.StackTempQuery\x1a,.spaceone.api.provisioning.v1.StackTempsInfo\"K\x82\xd3\xe4\x93\x02\x45\x12\x1c/provisioning/v1/stack_tempsZ%\"#/provisioning/v1/stack_temps/search\x12\xa5\x01\n\x0eget_stack_temp\x12\x31.spaceone.api.provisioning.v1.GetStackTempRequest\x1a+.spaceone.api.provisioning.v1.StackTempInfo\"3\x82\xd3\xe4\x93\x02-\x12+/provisioning/v1/stack_temp/{stack_temp_id}\x12\x9b\x01\n\x11update_stack_temp\x12\x34.spaceone.api.provisioning.v1.UpdateStackTempRequest\x1a+.spaceone.api.provisioning.v1.StackTempInfo\"#\x82\xd3\xe4\x93\x02\x1d\x1a\x1b/provisioning/v1/stack_temp\x12\x90\x01\n\x11\x64\x65lete_stack_temp\x12..spaceone.api.provisioning.v1.StackTempRequest\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-*+/provisioning/v1/stack_temp/{stack_temp_id}b\x06proto3')



_CREATESTACKTEMPREQUEST = DESCRIPTOR.message_types_by_name['CreateStackTempRequest']
_STACKTEMPREQUEST = DESCRIPTOR.message_types_by_name['StackTempRequest']
_GETSTACKTEMPREQUEST = DESCRIPTOR.message_types_by_name['GetStackTempRequest']
_UPDATESTACKTEMPREQUEST = DESCRIPTOR.message_types_by_name['UpdateStackTempRequest']
_STACKTEMPINFO = DESCRIPTOR.message_types_by_name['StackTempInfo']
_STACKTEMPSINFO = DESCRIPTOR.message_types_by_name['StackTempsInfo']
_STACKTEMPQUERY = DESCRIPTOR.message_types_by_name['StackTempQuery']
_ERRORINFO = DESCRIPTOR.message_types_by_name['ErrorInfo']
CreateStackTempRequest = _reflection.GeneratedProtocolMessageType('CreateStackTempRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTACKTEMPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateStackTempRequest)
  })
_sym_db.RegisterMessage(CreateStackTempRequest)

StackTempRequest = _reflection.GeneratedProtocolMessageType('StackTempRequest', (_message.Message,), {
  'DESCRIPTOR' : _STACKTEMPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackTempRequest)
  })
_sym_db.RegisterMessage(StackTempRequest)

GetStackTempRequest = _reflection.GeneratedProtocolMessageType('GetStackTempRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTACKTEMPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetStackTempRequest)
  })
_sym_db.RegisterMessage(GetStackTempRequest)

UpdateStackTempRequest = _reflection.GeneratedProtocolMessageType('UpdateStackTempRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTACKTEMPREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateStackTempRequest)
  })
_sym_db.RegisterMessage(UpdateStackTempRequest)

StackTempInfo = _reflection.GeneratedProtocolMessageType('StackTempInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKTEMPINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackTempInfo)
  })
_sym_db.RegisterMessage(StackTempInfo)

StackTempsInfo = _reflection.GeneratedProtocolMessageType('StackTempsInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKTEMPSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackTempsInfo)
  })
_sym_db.RegisterMessage(StackTempsInfo)

StackTempQuery = _reflection.GeneratedProtocolMessageType('StackTempQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKTEMPQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackTempQuery)
  })
_sym_db.RegisterMessage(StackTempQuery)

ErrorInfo = _reflection.GeneratedProtocolMessageType('ErrorInfo', (_message.Message,), {
  'DESCRIPTOR' : _ERRORINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_temp_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ErrorInfo)
  })
_sym_db.RegisterMessage(ErrorInfo)

_STACKTEMP = DESCRIPTOR.services_by_name['StackTemp']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STACKTEMP.methods_by_name['create_stack_temp']._options = None
  _STACKTEMP.methods_by_name['create_stack_temp']._serialized_options = b'\202\323\344\223\002\035\"\033/provisioning/v1/stack_temp'
  _STACKTEMP.methods_by_name['get_stack_temps']._options = None
  _STACKTEMP.methods_by_name['get_stack_temps']._serialized_options = b'\202\323\344\223\002E\022\034/provisioning/v1/stack_tempsZ%\"#/provisioning/v1/stack_temps/search'
  _STACKTEMP.methods_by_name['get_stack_temp']._options = None
  _STACKTEMP.methods_by_name['get_stack_temp']._serialized_options = b'\202\323\344\223\002-\022+/provisioning/v1/stack_temp/{stack_temp_id}'
  _STACKTEMP.methods_by_name['update_stack_temp']._options = None
  _STACKTEMP.methods_by_name['update_stack_temp']._serialized_options = b'\202\323\344\223\002\035\032\033/provisioning/v1/stack_temp'
  _STACKTEMP.methods_by_name['delete_stack_temp']._options = None
  _STACKTEMP.methods_by_name['delete_stack_temp']._serialized_options = b'\202\323\344\223\002-*+/provisioning/v1/stack_temp/{stack_temp_id}'
  _CREATESTACKTEMPREQUEST._serialized_start=203
  _CREATESTACKTEMPREQUEST._serialized_end=356
  _STACKTEMPREQUEST._serialized_start=358
  _STACKTEMPREQUEST._serialized_end=418
  _GETSTACKTEMPREQUEST._serialized_start=420
  _GETSTACKTEMPREQUEST._serialized_end=497
  _UPDATESTACKTEMPREQUEST._serialized_start=500
  _UPDATESTACKTEMPREQUEST._serialized_end=804
  _STACKTEMPINFO._serialized_start=807
  _STACKTEMPINFO._serialized_end=1142
  _STACKTEMPSINFO._serialized_start=1144
  _STACKTEMPSINFO._serialized_end=1243
  _STACKTEMPQUERY._serialized_start=1246
  _STACKTEMPQUERY._serialized_end=1424
  _ERRORINFO._serialized_start=1426
  _ERRORINFO._serialized_end=1519
  _STACKTEMP._serialized_start=1522
  _STACKTEMP._serialized_end=2353
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.provisioning.v1 import catalog_pb2 as spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2


class CatalogStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/create_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CreateCatalogRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
                )
        self.get_catalogs = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/get_catalogs',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogsInfo.FromString,
                )
        self.get_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/get_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.GetCatalogRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
                )
        self.update_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/update_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
                )
        self.delete_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/delete_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.publish_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/publish_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/stat',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.plan_catalog = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/plan_catalog',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.approval_process = channel.unary_unary(
                '/spaceone.api.provisioning.v1.Catalog/approval_process',
                request_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
                )


class CatalogServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_catalogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def publish_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def plan_catalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def approval_process(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CatalogServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.create_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CreateCatalogRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.SerializeToString,
            ),
            'get_catalogs': grpc.unary_unary_rpc_method_handler(
                    servicer.get_catalogs,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogsInfo.SerializeToString,
            ),
            'get_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.get_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.GetCatalogRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.SerializeToString,
            ),
            'update_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.update_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.SerializeToString,
            ),
            'delete_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'publish_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.publish_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'plan_catalog': grpc.unary_unary_rpc_method_handler(
                    servicer.plan_catalog,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'approval_process': grpc.unary_unary_rpc_method_handler(
                    servicer.approval_process,
                    request_deserializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.provisioning.v1.Catalog', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Catalog(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/create_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CreateCatalogRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_catalogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/get_catalogs',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogQuery.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/get_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.GetCatalogRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/update_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/delete_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def publish_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/publish_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/stat',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def plan_catalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/plan_catalog',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.PublishCatalogRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def approval_process(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.provisioning.v1.Catalog/approval_process',
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.UpdateCatalogRequest.SerializeToString,
            spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__pb2.CatalogInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/webhook.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/monitoring/v1/webhook.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x8c\x02\n\x11WebhookPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12O\n\x0cupgrade_mode\x18\x05 \x01(\x0e\x32\x39.spaceone.api.monitoring.v1.WebhookPluginInfo.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"\xb6\x01\n\x14\x43reateWebhookRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x0bplugin_info\x18\x02 \x01(\x0b\x32-.spaceone.api.monitoring.v1.WebhookPluginInfo\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"r\n\x14UpdateWebhookRequest\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x87\x02\n\x1aUpdateWebhookPluginRequest\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12X\n\x0cupgrade_mode\x18\x04 \x01(\x0e\x32\x42.spaceone.api.monitoring.v1.UpdateWebhookPluginRequest.UpgradeMode\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"7\n\x0eWebhookRequest\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"H\n\x11GetWebhookRequest\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xa7\x02\n\x0cWebhookQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nwebhook_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x44\n\x05state\x18\x04 \x01(\x0e\x32\x35.spaceone.api.monitoring.v1.WebhookQuery.WebhookState\x12\x12\n\naccess_key\x18\x05 \x01(\t\x12\x13\n\x0bwebhook_url\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"3\n\x0cWebhookState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xa5\x03\n\x0bWebhookInfo\x12\x12\n\nwebhook_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x43\n\x05state\x18\x03 \x01(\x0e\x32\x34.spaceone.api.monitoring.v1.WebhookInfo.WebhookState\x12\x12\n\naccess_key\x18\x04 \x01(\t\x12\x13\n\x0bwebhook_url\x18\x05 \x01(\t\x12+\n\ncapability\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x42\n\x0bplugin_info\x18\x07 \x01(\x0b\x32-.spaceone.api.monitoring.v1.WebhookPluginInfo\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"3\n\x0cWebhookState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"]\n\x0cWebhooksInfo\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\'.spaceone.api.monitoring.v1.WebhookInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"[\n\x10WebhookStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa2\x0b\n\x07Webhook\x12\x84\x01\n\x06\x63reate\x12\x30.spaceone.api.monitoring.v1.CreateWebhookRequest\x1a\'.spaceone.api.monitoring.v1.WebhookInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/monitoring/v1/webhooks\x12\x90\x01\n\x06update\x12\x30.spaceone.api.monitoring.v1.UpdateWebhookRequest\x1a\'.spaceone.api.monitoring.v1.WebhookInfo\"+\x82\xd3\xe4\x93\x02%\x1a#/monitoring/v1/webhook/{webhook_id}\x12\xa4\x01\n\rupdate_plugin\x12\x36.spaceone.api.monitoring.v1.UpdateWebhookPluginRequest\x1a\'.spaceone.api.monitoring.v1.WebhookInfo\"2\x82\xd3\xe4\x93\x02,\x1a*/monitoring/v1/webhook/{webhook_id}/plugin\x12\x8e\x01\n\rverify_plugin\x12*.spaceone.api.monitoring.v1.WebhookRequest\x1a\x16.google.protobuf.Empty\"9\x82\xd3\xe4\x93\x02\x33\"1/monitoring/v1/webhook/{webhook_id}/plugin/verify\x12\x91\x01\n\x06\x65nable\x12*.spaceone.api.monitoring.v1.WebhookRequest\x1a\'.spaceone.api.monitoring.v1.WebhookInfo\"2\x82\xd3\xe4\x93\x02,\x1a*/monitoring/v1/webhook/{webhook_id}/enable\x12\x93\x01\n\x07\x64isable\x12*.spaceone.api.monitoring.v1.WebhookRequest\x1a\'.spaceone.api.monitoring.v1.WebhookInfo\"3\x82\xd3\xe4\x93\x02-\x1a+/monitoring/v1/webhook/{webhook_id}/disable\x12y\n\x06\x64\x65lete\x12*.spaceone.api.monitoring.v1.WebhookRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%*#/monitoring/v1/webhook/{webhook_id}\x12\x8a\x01\n\x03get\x12-.spaceone.api.monitoring.v1.GetWebhookRequest\x1a\'.spaceone.api.monitoring.v1.WebhookInfo\"+\x82\xd3\xe4\x93\x02%\x12#/monitoring/v1/webhook/{webhook_id}\x12\x9d\x01\n\x04list\x12(.spaceone.api.monitoring.v1.WebhookQuery\x1a(.spaceone.api.monitoring.v1.WebhooksInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/monitoring/v1/webhooksZ \"\x1e/monitoring/v1/webhooks/search\x12s\n\x04stat\x12,.spaceone.api.monitoring.v1.WebhookStatQuery\x1a\x17.google.protobuf.Struct\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/monitoring/v1/webhooks/statb\x06proto3')



_WEBHOOKPLUGININFO = DESCRIPTOR.message_types_by_name['WebhookPluginInfo']
_CREATEWEBHOOKREQUEST = DESCRIPTOR.message_types_by_name['CreateWebhookRequest']
_UPDATEWEBHOOKREQUEST = DESCRIPTOR.message_types_by_name['UpdateWebhookRequest']
_UPDATEWEBHOOKPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateWebhookPluginRequest']
_WEBHOOKREQUEST = DESCRIPTOR.message_types_by_name['WebhookRequest']
_GETWEBHOOKREQUEST = DESCRIPTOR.message_types_by_name['GetWebhookRequest']
_WEBHOOKQUERY = DESCRIPTOR.message_types_by_name['WebhookQuery']
_WEBHOOKINFO = DESCRIPTOR.message_types_by_name['WebhookInfo']
_WEBHOOKSINFO = DESCRIPTOR.message_types_by_name['WebhooksInfo']
_WEBHOOKSTATQUERY = DESCRIPTOR.message_types_by_name['WebhookStatQuery']
_WEBHOOKPLUGININFO_UPGRADEMODE = _WEBHOOKPLUGININFO.enum_types_by_name['UpgradeMode']
_UPDATEWEBHOOKPLUGINREQUEST_UPGRADEMODE = _UPDATEWEBHOOKPLUGINREQUEST.enum_types_by_name['UpgradeMode']
_WEBHOOKQUERY_WEBHOOKSTATE = _WEBHOOKQUERY.enum_types_by_name['WebhookState']
_WEBHOOKINFO_WEBHOOKSTATE = _WEBHOOKINFO.enum_types_by_name['WebhookState']
WebhookPluginInfo = _reflection.GeneratedProtocolMessageType('WebhookPluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKPLUGININFO,
  '__module__' : 'spaceone.api.monitoring.v1.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.WebhookPluginInfo)
  })
_sym_db.RegisterMessage(WebhookPluginInfo)

CreateWebhookRequest = _reflection.GeneratedProtocolMessageType('CreateWebhookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBHOOKREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateWebhookRequest)
  })
_sym_db.RegisterMessage(CreateWebhookRequest)

UpdateWebhookRequest = _reflection.GeneratedProtocolMessageType('UpdateWebhookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBHOOKREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateWebhookRequest)
  })
_sym_db.RegisterMessage(UpdateWebhookRequest)

UpdateWebhookPluginRequest = _reflection.GeneratedProtocolMessageType('UpdateWebhookPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBHOOKPLUGINREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateWebhookPluginRequest)
  })
_sym_db.RegisterMessage(UpdateWebhookPluginRequest)

WebhookRequest = _reflection.GeneratedProtocolMessageType('WebhookRequest', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.WebhookRequest)
  })
_sym_db.RegisterMessage(WebhookRequest)

GetWebhookRequest = _reflection.GeneratedProtocolMessageType('GetWebhookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBHOOKREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetWebhookRequest)
  })
_sym_db.RegisterMessage(GetWebhookRequest)

WebhookQuery = _reflection.GeneratedProtocolMessageType('WebhookQuery', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.WebhookQuery)
  })
_sym_db.RegisterMessage(WebhookQuery)

WebhookInfo = _reflection.GeneratedProtocolMessageType('WebhookInfo', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKINFO,
  '__module__' : 'spaceone.api.monitoring.v1.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.WebhookInfo)
  })
_sym_db.RegisterMessage(WebhookInfo)

WebhooksInfo = _reflection.GeneratedProtocolMessageType('WebhooksInfo', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKSINFO,
  '__module__' : 'spaceone.api.monitoring.v1.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.WebhooksInfo)
  })
_sym_db.RegisterMessage(WebhooksInfo)

WebhookStatQuery = _reflection.GeneratedProtocolMessageType('WebhookStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _WEBHOOKSTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.webhook_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.WebhookStatQuery)
  })
_sym_db.RegisterMessage(WebhookStatQuery)

_WEBHOOK = DESCRIPTOR.services_by_name['Webhook']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WEBHOOK.methods_by_name['create']._options = None
  _WEBHOOK.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\031\"\027/monitoring/v1/webhooks'
  _WEBHOOK.methods_by_name['update']._options = None
  _WEBHOOK.methods_by_name['update']._serialized_options = b'\202\323\344\223\002%\032#/monitoring/v1/webhook/{webhook_id}'
  _WEBHOOK.methods_by_name['update_plugin']._options = None
  _WEBHOOK.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\002,\032*/monitoring/v1/webhook/{webhook_id}/plugin'
  _WEBHOOK.methods_by_name['verify_plugin']._options = None
  _WEBHOOK.methods_by_name['verify_plugin']._serialized_options = b'\202\323\344\223\0023\"1/monitoring/v1/webhook/{webhook_id}/plugin/verify'
  _WEBHOOK.methods_by_name['enable']._options = None
  _WEBHOOK.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002,\032*/monitoring/v1/webhook/{webhook_id}/enable'
  _WEBHOOK.methods_by_name['disable']._options = None
  _WEBHOOK.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002-\032+/monitoring/v1/webhook/{webhook_id}/disable'
  _WEBHOOK.methods_by_name['delete']._options = None
  _WEBHOOK.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002%*#/monitoring/v1/webhook/{webhook_id}'
  _WEBHOOK.methods_by_name['get']._options = None
  _WEBHOOK.methods_by_name['get']._serialized_options = b'\202\323\344\223\002%\022#/monitoring/v1/webhook/{webhook_id}'
  _WEBHOOK.methods_by_name['list']._options = None
  _WEBHOOK.methods_by_name['list']._serialized_options = b'\202\323\344\223\002;\022\027/monitoring/v1/webhooksZ \"\036/monitoring/v1/webhooks/search'
  _WEBHOOK.methods_by_name['stat']._options = None
  _WEBHOOK.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\036\"\034/monitoring/v1/webhooks/stat'
  _WEBHOOKPLUGININFO._serialized_start=196
  _WEBHOOKPLUGININFO._serialized_end=464
  _WEBHOOKPLUGININFO_UPGRADEMODE._serialized_start=419
  _WEBHOOKPLUGININFO_UPGRADEMODE._serialized_end=464
  _CREATEWEBHOOKREQUEST._serialized_start=467
  _CREATEWEBHOOKREQUEST._serialized_end=649
  _UPDATEWEBHOOKREQUEST._serialized_start=651
  _UPDATEWEBHOOKREQUEST._serialized_end=765
  _UPDATEWEBHOOKPLUGINREQUEST._serialized_start=768
  _UPDATEWEBHOOKPLUGINREQUEST._serialized_end=1031
  _UPDATEWEBHOOKPLUGINREQUEST_UPGRADEMODE._serialized_start=419
  _UPDATEWEBHOOKPLUGINREQUEST_UPGRADEMODE._serialized_end=464
  _WEBHOOKREQUEST._serialized_start=1033
  _WEBHOOKREQUEST._serialized_end=1088
  _GETWEBHOOKREQUEST._serialized_start=1090
  _GETWEBHOOKREQUEST._serialized_end=1162
  _WEBHOOKQUERY._serialized_start=1165
  _WEBHOOKQUERY._serialized_end=1460
  _WEBHOOKQUERY_WEBHOOKSTATE._serialized_start=1409
  _WEBHOOKQUERY_WEBHOOKSTATE._serialized_end=1460
  _WEBHOOKINFO._serialized_start=1463
  _WEBHOOKINFO._serialized_end=1884
  _WEBHOOKINFO_WEBHOOKSTATE._serialized_start=1409
  _WEBHOOKINFO_WEBHOOKSTATE._serialized_end=1460
  _WEBHOOKSINFO._serialized_start=1886
  _WEBHOOKSINFO._serialized_end=1979
  _WEBHOOKSTATQUERY._serialized_start=1981
  _WEBHOOKSTATQUERY._serialized_end=2072
  _WEBHOOK._serialized_start=2075
  _WEBHOOK._serialized_end=3517
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/board/v1/board.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!spaceone/api/board/v1/board.proto\x12\x15spaceone.api.board.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"]\n\x12\x43reateBoardRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncategories\x18\x02 \x03(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"[\n\x12UpdateBoardRequest\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"A\n\x19SetBoardCategoriesRequest\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x12\n\ncategories\x18\x02 \x03(\t\" \n\x0c\x42oardRequest\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\"1\n\x0fGetBoardRequest\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"X\n\nBoardQuery\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12*\n\x05query\x18\x03 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\"F\n\x0e\x42oardStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\"z\n\tBoardInfo\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncategories\x18\x03 \x03(\t\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x0b \x01(\t\"T\n\nBoardsInfo\x12\x31\n\x07results\x18\x01 \x03(\x0b\x32 .spaceone.api.board.v1.BoardInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xd8\x06\n\x05\x42oard\x12o\n\x06\x63reate\x12).spaceone.api.board.v1.CreateBoardRequest\x1a .spaceone.api.board.v1.BoardInfo\"\x18\x82\xd3\xe4\x93\x02\x12\"\x10/board/v1/boards\x12y\n\x06update\x12).spaceone.api.board.v1.UpdateBoardRequest\x1a .spaceone.api.board.v1.BoardInfo\"\"\x82\xd3\xe4\x93\x02\x1c\x1a\x1a/board/v1/board/{board_id}\x12\x97\x01\n\x0eset_categories\x12\x30.spaceone.api.board.v1.SetBoardCategoriesRequest\x1a .spaceone.api.board.v1.BoardInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/board/v1/board/{board_id}/set-categories\x12i\n\x06\x64\x65lete\x12#.spaceone.api.board.v1.BoardRequest\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/board/v1/board/{board_id}\x12s\n\x03get\x12&.spaceone.api.board.v1.GetBoardRequest\x1a .spaceone.api.board.v1.BoardInfo\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/board/v1/board/{board_id}\x12\x81\x01\n\x04list\x12!.spaceone.api.board.v1.BoardQuery\x1a!.spaceone.api.board.v1.BoardsInfo\"3\x82\xd3\xe4\x93\x02-\x12\x10/board/v1/boardsZ\x19\"\x17/board/v1/boards/search\x12\x65\n\x04stat\x12%.spaceone.api.board.v1.BoardStatQuery\x1a\x17.google.protobuf.Struct\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/board/v1/boards/statb\x06proto3')



_CREATEBOARDREQUEST = DESCRIPTOR.message_types_by_name['CreateBoardRequest']
_UPDATEBOARDREQUEST = DESCRIPTOR.message_types_by_name['UpdateBoardRequest']
_SETBOARDCATEGORIESREQUEST = DESCRIPTOR.message_types_by_name['SetBoardCategoriesRequest']
_BOARDREQUEST = DESCRIPTOR.message_types_by_name['BoardRequest']
_GETBOARDREQUEST = DESCRIPTOR.message_types_by_name['GetBoardRequest']
_BOARDQUERY = DESCRIPTOR.message_types_by_name['BoardQuery']
_BOARDSTATQUERY = DESCRIPTOR.message_types_by_name['BoardStatQuery']
_BOARDINFO = DESCRIPTOR.message_types_by_name['BoardInfo']
_BOARDSINFO = DESCRIPTOR.message_types_by_name['BoardsInfo']
CreateBoardRequest = _reflection.GeneratedProtocolMessageType('CreateBoardRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBOARDREQUEST,
  '__module__' : 'spaceone.api.board.v1.board_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.CreateBoardRequest)
  })
_sym_db.RegisterMessage(CreateBoardRequest)

UpdateBoardRequest = _reflection.GeneratedProtocolMessageType('UpdateBoardRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBOARDREQUEST,
  '__module__' : 'spaceone.api.board.v1.board_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.UpdateBoardRequest)
  })
_sym_db.RegisterMessage(UpdateBoardRequest)

SetBoardCategoriesRequest = _reflection.GeneratedProtocolMessageType('SetBoardCategoriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETBOARDCATEGORIESREQUEST,
  '__module__' : 'spaceone.api.board.v1.board_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.SetBoardCategoriesRequest)
  })
_sym_db.RegisterMessage(SetBoardCategoriesRequest)

BoardRequest = _reflection.GeneratedProtocolMessageType('BoardRequest', (_message.Message,), {
  'DESCRIPTOR' : _BOARDREQUEST,
  '__module__' : 'spaceone.api.board.v1.board_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.BoardRequest)
  })
_sym_db.RegisterMessage(BoardRequest)

GetBoardRequest = _reflection.GeneratedProtocolMessageType('GetBoardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBOARDREQUEST,
  '__module__' : 'spaceone.api.board.v1.board_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.GetBoardRequest)
  })
_sym_db.RegisterMessage(GetBoardRequest)

BoardQuery = _reflection.GeneratedProtocolMessageType('BoardQuery', (_message.Message,), {
  'DESCRIPTOR' : _BOARDQUERY,
  '__module__' : 'spaceone.api.board.v1.board_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.BoardQuery)
  })
_sym_db.RegisterMessage(BoardQuery)

BoardStatQuery = _reflection.GeneratedProtocolMessageType('BoardStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _BOARDSTATQUERY,
  '__module__' : 'spaceone.api.board.v1.board_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.BoardStatQuery)
  })
_sym_db.RegisterMessage(BoardStatQuery)

BoardInfo = _reflection.GeneratedProtocolMessageType('BoardInfo', (_message.Message,), {
  'DESCRIPTOR' : _BOARDINFO,
  '__module__' : 'spaceone.api.board.v1.board_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.BoardInfo)
  })
_sym_db.RegisterMessage(BoardInfo)

BoardsInfo = _reflection.GeneratedProtocolMessageType('BoardsInfo', (_message.Message,), {
  'DESCRIPTOR' : _BOARDSINFO,
  '__module__' : 'spaceone.api.board.v1.board_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.BoardsInfo)
  })
_sym_db.RegisterMessage(BoardsInfo)

_BOARD = DESCRIPTOR.services_by_name['Board']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BOARD.methods_by_name['create']._options = None
  _BOARD.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\022\"\020/board/v1/boards'
  _BOARD.methods_by_name['update']._options = None
  _BOARD.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\034\032\032/board/v1/board/{board_id}'
  _BOARD.methods_by_name['set_categories']._options = None
  _BOARD.methods_by_name['set_categories']._serialized_options = b'\202\323\344\223\002+\032)/board/v1/board/{board_id}/set-categories'
  _BOARD.methods_by_name['delete']._options = None
  _BOARD.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\034*\032/board/v1/board/{board_id}'
  _BOARD.methods_by_name['get']._options = None
  _BOARD.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\034\022\032/board/v1/board/{board_id}'
  _BOARD.methods_by_name['list']._options = None
  _BOARD.methods_by_name['list']._serialized_options = b'\202\323\344\223\002-\022\020/board/v1/boardsZ\031\"\027/board/v1/boards/search'
  _BOARD.methods_by_name['stat']._options = None
  _BOARD.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\027\"\025/board/v1/boards/stat'
  _CREATEBOARDREQUEST._serialized_start=183
  _CREATEBOARDREQUEST._serialized_end=276
  _UPDATEBOARDREQUEST._serialized_start=278
  _UPDATEBOARDREQUEST._serialized_end=369
  _SETBOARDCATEGORIESREQUEST._serialized_start=371
  _SETBOARDCATEGORIESREQUEST._serialized_end=436
  _BOARDREQUEST._serialized_start=438
  _BOARDREQUEST._serialized_end=470
  _GETBOARDREQUEST._serialized_start=472
  _GETBOARDREQUEST._serialized_end=521
  _BOARDQUERY._serialized_start=523
  _BOARDQUERY._serialized_end=611
  _BOARDSTATQUERY._serialized_start=613
  _BOARDSTATQUERY._serialized_end=683
  _BOARDINFO._serialized_start=685
  _BOARDINFO._serialized_end=807
  _BOARDSINFO._serialized_start=809
  _BOARDSINFO._serialized_end=893
  _BOARD._serialized_start=896
  _BOARD._serialized_end=1752
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/project_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.identity.v1 import role_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/identity/v1/project_group.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a#spaceone/api/identity/v1/role.proto\"\x84\x01\n\x19\x43reateProjectGroupRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1f\n\x17parent_project_group_id\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xc4\x01\n\x19UpdateProjectGroupRequest\x12\x18\n\x10project_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1f\n\x17parent_project_group_id\x18\x03 \x01(\t\x12$\n\x1crelease_parent_project_group\x18\x04 \x01(\x08\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"B\n\x13ProjectGroupRequest\x12\x18\n\x10project_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"S\n\x16GetProjectGroupRequest\x12\x18\n\x10project_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb2\x01\n\x11ProjectGroupQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x18\n\x10project_group_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1f\n\x17parent_project_group_id\x18\x04 \x01(\t\x12\x15\n\rauthor_within\x18\x05 \x01(\x08\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"\xeb\x01\n\x10ProjectGroupInfo\x12\x18\n\x10project_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12M\n\x19parent_project_group_info\x18\x04 \x01(\x0b\x32*.spaceone.api.identity.v1.ProjectGroupInfo\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\"e\n\x11ProjectGroupsInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.identity.v1.ProjectGroupInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xda\x01\n\x1c\x41\x64\x64ProjectGroupMemberRequest\x12\x18\n\x10project_group_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0f\n\x07role_id\x18\x03 \x01(\t\x12*\n\x06labels\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x18\n\x10is_external_user\x18\x07 \x01(\x08\"\xb2\x01\n\x1fModifyProjectGroupMemberRequest\x12\x18\n\x10project_group_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12*\n\x06labels\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"_\n\x1fRemoveProjectGroupMemberRequest\x12\x18\n\x10project_group_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"\xb3\x01\n\x17ProjectGroupMemberQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x18\n\x10project_group_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x0f\n\x07role_id\x18\x04 \x01(\t\x12\x1d\n\x15include_parent_member\x18\x05 \x01(\x08\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"\xdb\x02\n\x1bProjectGroupRoleBindingInfo\x12\x17\n\x0frole_binding_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x35\n\trole_info\x18\x04 \x01(\x0b\x32\".spaceone.api.identity.v1.RoleInfo\x12\x46\n\x12project_group_info\x18\x05 \x01(\x0b\x32*.spaceone.api.identity.v1.ProjectGroupInfo\x12*\n\x06labels\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"{\n\x1cProjectGroupRoleBindingsInfo\x12\x46\n\x07results\x18\x01 \x03(\x0b\x32\x35.spaceone.api.identity.v1.ProjectGroupRoleBindingInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x86\x01\n\x18ProjectGroupProjectQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x18\n\x10project_group_id\x18\x02 \x01(\t\x12\x11\n\trecursive\x18\x03 \x01(\x08\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xe5\x01\n\x17ProjectGroupProjectInfo\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x46\n\x12project_group_info\x18\x04 \x01(\x0b\x32*.spaceone.api.identity.v1.ProjectGroupInfo\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\"s\n\x18ProjectGroupProjectsInfo\x12\x42\n\x07results\x18\x01 \x03(\x0b\x32\x31.spaceone.api.identity.v1.ProjectGroupProjectInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"`\n\x15ProjectGroupStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xac\x0f\n\x0cProjectGroup\x12\x8e\x01\n\x06\x63reate\x12\x33.spaceone.api.identity.v1.CreateProjectGroupRequest\x1a*.spaceone.api.identity.v1.ProjectGroupInfo\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/identity/v1/project-groups\x12\xa0\x01\n\x06update\x12\x33.spaceone.api.identity.v1.UpdateProjectGroupRequest\x1a*.spaceone.api.identity.v1.ProjectGroupInfo\"5\x82\xd3\xe4\x93\x02/\x1a-/identity/v1/project-group/{project_group_id}\x12\x80\x01\n\x06\x64\x65lete\x12-.spaceone.api.identity.v1.ProjectGroupRequest\x1a\x16.google.protobuf.Empty\"/\x82\xd3\xe4\x93\x02)*\'/identity/v1/project-group/{project_id}\x12\x9a\x01\n\x03get\x12\x30.spaceone.api.identity.v1.GetProjectGroupRequest\x1a*.spaceone.api.identity.v1.ProjectGroupInfo\"5\x82\xd3\xe4\x93\x02/\x12-/identity/v1/project-group/{project_group_id}\x12\xab\x01\n\x04list\x12+.spaceone.api.identity.v1.ProjectGroupQuery\x1a+.spaceone.api.identity.v1.ProjectGroupsInfo\"I\x82\xd3\xe4\x93\x02\x43\x12\x1b/identity/v1/project-groupsZ$\"\"/identity/v1/project-groups/search\x12z\n\x04stat\x12/.spaceone.api.identity.v1.ProjectGroupStatQuery\x1a\x17.google.protobuf.Struct\"(\x82\xd3\xe4\x93\x02\"\" /identity/v1/project-groups/stat\x12\xba\x01\n\nadd_member\x12\x36.spaceone.api.identity.v1.AddProjectGroupMemberRequest\x1a\x35.spaceone.api.identity.v1.ProjectGroupRoleBindingInfo\"=\x82\xd3\xe4\x93\x02\x37\"5/identity/v1/project-group/{project_group_id}/members\x12\xc9\x01\n\rmodify_member\x12\x39.spaceone.api.identity.v1.ModifyProjectGroupMemberRequest\x1a\x35.spaceone.api.identity.v1.ProjectGroupRoleBindingInfo\"F\x82\xd3\xe4\x93\x02@\x1a>/identity/v1/project-group/{project_group_id}/member/{user_id}\x12\xaa\x01\n\rremove_member\x12\x39.spaceone.api.identity.v1.RemoveProjectGroupMemberRequest\x1a\x16.google.protobuf.Empty\"F\x82\xd3\xe4\x93\x02@*>/identity/v1/project-group/{project_group_id}/member/{user_id}\x12\xf2\x01\n\x0clist_members\x12\x31.spaceone.api.identity.v1.ProjectGroupMemberQuery\x1a\x36.spaceone.api.identity.v1.ProjectGroupRoleBindingsInfo\"w\x82\xd3\xe4\x93\x02q\x12\x35/identity/v1/project-group/{project_group_id}/membersZ8\"6/identity/v1/project-group/{project_id}/members/search\x12\xf2\x01\n\rlist_projects\x12\x32.spaceone.api.identity.v1.ProjectGroupProjectQuery\x1a\x32.spaceone.api.identity.v1.ProjectGroupProjectsInfo\"y\x82\xd3\xe4\x93\x02s\x12\x36/identity/v1/project-group/{project_group_id}/projectsZ9\"7/identity/v1/project-group/{project_id}/projects/searchb\x06proto3')



_CREATEPROJECTGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectGroupRequest']
_UPDATEPROJECTGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectGroupRequest']
_PROJECTGROUPREQUEST = DESCRIPTOR.message_types_by_name['ProjectGroupRequest']
_GETPROJECTGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetProjectGroupRequest']
_PROJECTGROUPQUERY = DESCRIPTOR.message_types_by_name['ProjectGroupQuery']
_PROJECTGROUPINFO = DESCRIPTOR.message_types_by_name['ProjectGroupInfo']
_PROJECTGROUPSINFO = DESCRIPTOR.message_types_by_name['ProjectGroupsInfo']
_ADDPROJECTGROUPMEMBERREQUEST = DESCRIPTOR.message_types_by_name['AddProjectGroupMemberRequest']
_MODIFYPROJECTGROUPMEMBERREQUEST = DESCRIPTOR.message_types_by_name['ModifyProjectGroupMemberRequest']
_REMOVEPROJECTGROUPMEMBERREQUEST = DESCRIPTOR.message_types_by_name['RemoveProjectGroupMemberRequest']
_PROJECTGROUPMEMBERQUERY = DESCRIPTOR.message_types_by_name['ProjectGroupMemberQuery']
_PROJECTGROUPROLEBINDINGINFO = DESCRIPTOR.message_types_by_name['ProjectGroupRoleBindingInfo']
_PROJECTGROUPROLEBINDINGSINFO = DESCRIPTOR.message_types_by_name['ProjectGroupRoleBindingsInfo']
_PROJECTGROUPPROJECTQUERY = DESCRIPTOR.message_types_by_name['ProjectGroupProjectQuery']
_PROJECTGROUPPROJECTINFO = DESCRIPTOR.message_types_by_name['ProjectGroupProjectInfo']
_PROJECTGROUPPROJECTSINFO = DESCRIPTOR.message_types_by_name['ProjectGroupProjectsInfo']
_PROJECTGROUPSTATQUERY = DESCRIPTOR.message_types_by_name['ProjectGroupStatQuery']
CreateProjectGroupRequest = _reflection.GeneratedProtocolMessageType('CreateProjectGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTGROUPREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateProjectGroupRequest)
  })
_sym_db.RegisterMessage(CreateProjectGroupRequest)

UpdateProjectGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTGROUPREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateProjectGroupRequest)
  })
_sym_db.RegisterMessage(UpdateProjectGroupRequest)

ProjectGroupRequest = _reflection.GeneratedProtocolMessageType('ProjectGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupRequest)
  })
_sym_db.RegisterMessage(ProjectGroupRequest)

GetProjectGroupRequest = _reflection.GeneratedProtocolMessageType('GetProjectGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTGROUPREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetProjectGroupRequest)
  })
_sym_db.RegisterMessage(GetProjectGroupRequest)

ProjectGroupQuery = _reflection.GeneratedProtocolMessageType('ProjectGroupQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPQUERY,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupQuery)
  })
_sym_db.RegisterMessage(ProjectGroupQuery)

ProjectGroupInfo = _reflection.GeneratedProtocolMessageType('ProjectGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPINFO,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupInfo)
  })
_sym_db.RegisterMessage(ProjectGroupInfo)

ProjectGroupsInfo = _reflection.GeneratedProtocolMessageType('ProjectGroupsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPSINFO,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupsInfo)
  })
_sym_db.RegisterMessage(ProjectGroupsInfo)

AddProjectGroupMemberRequest = _reflection.GeneratedProtocolMessageType('AddProjectGroupMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPROJECTGROUPMEMBERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.AddProjectGroupMemberRequest)
  })
_sym_db.RegisterMessage(AddProjectGroupMemberRequest)

ModifyProjectGroupMemberRequest = _reflection.GeneratedProtocolMessageType('ModifyProjectGroupMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYPROJECTGROUPMEMBERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ModifyProjectGroupMemberRequest)
  })
_sym_db.RegisterMessage(ModifyProjectGroupMemberRequest)

RemoveProjectGroupMemberRequest = _reflection.GeneratedProtocolMessageType('RemoveProjectGroupMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPROJECTGROUPMEMBERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RemoveProjectGroupMemberRequest)
  })
_sym_db.RegisterMessage(RemoveProjectGroupMemberRequest)

ProjectGroupMemberQuery = _reflection.GeneratedProtocolMessageType('ProjectGroupMemberQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPMEMBERQUERY,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupMemberQuery)
  })
_sym_db.RegisterMessage(ProjectGroupMemberQuery)

ProjectGroupRoleBindingInfo = _reflection.GeneratedProtocolMessageType('ProjectGroupRoleBindingInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPROLEBINDINGINFO,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupRoleBindingInfo)
  })
_sym_db.RegisterMessage(ProjectGroupRoleBindingInfo)

ProjectGroupRoleBindingsInfo = _reflection.GeneratedProtocolMessageType('ProjectGroupRoleBindingsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPROLEBINDINGSINFO,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupRoleBindingsInfo)
  })
_sym_db.RegisterMessage(ProjectGroupRoleBindingsInfo)

ProjectGroupProjectQuery = _reflection.GeneratedProtocolMessageType('ProjectGroupProjectQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPPROJECTQUERY,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupProjectQuery)
  })
_sym_db.RegisterMessage(ProjectGroupProjectQuery)

ProjectGroupProjectInfo = _reflection.GeneratedProtocolMessageType('ProjectGroupProjectInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPPROJECTINFO,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupProjectInfo)
  })
_sym_db.RegisterMessage(ProjectGroupProjectInfo)

ProjectGroupProjectsInfo = _reflection.GeneratedProtocolMessageType('ProjectGroupProjectsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPPROJECTSINFO,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupProjectsInfo)
  })
_sym_db.RegisterMessage(ProjectGroupProjectsInfo)

ProjectGroupStatQuery = _reflection.GeneratedProtocolMessageType('ProjectGroupStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTGROUPSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.project_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectGroupStatQuery)
  })
_sym_db.RegisterMessage(ProjectGroupStatQuery)

_PROJECTGROUP = DESCRIPTOR.services_by_name['ProjectGroup']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECTGROUP.methods_by_name['create']._options = None
  _PROJECTGROUP.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\035\"\033/identity/v1/project-groups'
  _PROJECTGROUP.methods_by_name['update']._options = None
  _PROJECTGROUP.methods_by_name['update']._serialized_options = b'\202\323\344\223\002/\032-/identity/v1/project-group/{project_group_id}'
  _PROJECTGROUP.methods_by_name['delete']._options = None
  _PROJECTGROUP.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002)*\'/identity/v1/project-group/{project_id}'
  _PROJECTGROUP.methods_by_name['get']._options = None
  _PROJECTGROUP.methods_by_name['get']._serialized_options = b'\202\323\344\223\002/\022-/identity/v1/project-group/{project_group_id}'
  _PROJECTGROUP.methods_by_name['list']._options = None
  _PROJECTGROUP.methods_by_name['list']._serialized_options = b'\202\323\344\223\002C\022\033/identity/v1/project-groupsZ$\"\"/identity/v1/project-groups/search'
  _PROJECTGROUP.methods_by_name['stat']._options = None
  _PROJECTGROUP.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\"\" /identity/v1/project-groups/stat'
  _PROJECTGROUP.methods_by_name['add_member']._options = None
  _PROJECTGROUP.methods_by_name['add_member']._serialized_options = b'\202\323\344\223\0027\"5/identity/v1/project-group/{project_group_id}/members'
  _PROJECTGROUP.methods_by_name['modify_member']._options = None
  _PROJECTGROUP.methods_by_name['modify_member']._serialized_options = b'\202\323\344\223\002@\032>/identity/v1/project-group/{project_group_id}/member/{user_id}'
  _PROJECTGROUP.methods_by_name['remove_member']._options = None
  _PROJECTGROUP.methods_by_name['remove_member']._serialized_options = b'\202\323\344\223\002@*>/identity/v1/project-group/{project_group_id}/member/{user_id}'
  _PROJECTGROUP.methods_by_name['list_members']._options = None
  _PROJECTGROUP.methods_by_name['list_members']._serialized_options = b'\202\323\344\223\002q\0225/identity/v1/project-group/{project_group_id}/membersZ8\"6/identity/v1/project-group/{project_id}/members/search'
  _PROJECTGROUP.methods_by_name['list_projects']._options = None
  _PROJECTGROUP.methods_by_name['list_projects']._serialized_options = b'\202\323\344\223\002s\0226/identity/v1/project-group/{project_group_id}/projectsZ9\"7/identity/v1/project-group/{project_id}/projects/search'
  _CREATEPROJECTGROUPREQUEST._serialized_start=235
  _CREATEPROJECTGROUPREQUEST._serialized_end=367
  _UPDATEPROJECTGROUPREQUEST._serialized_start=370
  _UPDATEPROJECTGROUPREQUEST._serialized_end=566
  _PROJECTGROUPREQUEST._serialized_start=568
  _PROJECTGROUPREQUEST._serialized_end=634
  _GETPROJECTGROUPREQUEST._serialized_start=636
  _GETPROJECTGROUPREQUEST._serialized_end=719
  _PROJECTGROUPQUERY._serialized_start=722
  _PROJECTGROUPQUERY._serialized_end=900
  _PROJECTGROUPINFO._serialized_start=903
  _PROJECTGROUPINFO._serialized_end=1138
  _PROJECTGROUPSINFO._serialized_start=1140
  _PROJECTGROUPSINFO._serialized_end=1241
  _ADDPROJECTGROUPMEMBERREQUEST._serialized_start=1244
  _ADDPROJECTGROUPMEMBERREQUEST._serialized_end=1462
  _MODIFYPROJECTGROUPMEMBERREQUEST._serialized_start=1465
  _MODIFYPROJECTGROUPMEMBERREQUEST._serialized_end=1643
  _REMOVEPROJECTGROUPMEMBERREQUEST._serialized_start=1645
  _REMOVEPROJECTGROUPMEMBERREQUEST._serialized_end=1740
  _PROJECTGROUPMEMBERQUERY._serialized_start=1743
  _PROJECTGROUPMEMBERQUERY._serialized_end=1922
  _PROJECTGROUPROLEBINDINGINFO._serialized_start=1925
  _PROJECTGROUPROLEBINDINGINFO._serialized_end=2272
  _PROJECTGROUPROLEBINDINGSINFO._serialized_start=2274
  _PROJECTGROUPROLEBINDINGSINFO._serialized_end=2397
  _PROJECTGROUPPROJECTQUERY._serialized_start=2400
  _PROJECTGROUPPROJECTQUERY._serialized_end=2534
  _PROJECTGROUPPROJECTINFO._serialized_start=2537
  _PROJECTGROUPPROJECTINFO._serialized_end=2766
  _PROJECTGROUPPROJECTSINFO._serialized_start=2768
  _PROJECTGROUPPROJECTSINFO._serialized_end=2883
  _PROJECTGROUPSTATQUERY._serialized_start=2885
  _PROJECTGROUPSTATQUERY._serialized_end=2981
  _PROJECTGROUP._serialized_start=2984
  _PROJECTGROUP._serialized_end=4948
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/savings_azure.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-spaceone/api/inventory/v1/savings_azure.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"T\n\x15SavingsCollectRequest\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"z\n\x15SavingsSummaryRequest\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x12\n\nstart_date\x18\x04 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x05 \x01(\t\"\xab\x01\n\x10GetCoverageQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x1a\n\x12service_account_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x12\n\nstart_date\x18\x05 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x06 \x01(\t2\xe8\x04\n\x0cSavingsAzure\x12\x9c\x01\n\x15\x63reate_recommendation\x12\x30.spaceone.api.inventory.v1.SavingsCollectRequest\x1a\x16.google.protobuf.Empty\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/inventory/v1/savings-azure/create_recommendation\x12\x92\x01\n\x10\x63reate_inventory\x12\x30.spaceone.api.inventory.v1.SavingsCollectRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\x12,/inventory/v1/savings-azure/create_inventory\x12\x8e\x01\n\x0e\x63reate_summary\x12\x30.spaceone.api.inventory.v1.SavingsSummaryRequest\x1a\x16.google.protobuf.Empty\"2\x82\xd3\xe4\x93\x02,\x12*/inventory/v1/savings-azure/create_summary\x12\x92\x01\n\x12get_coverage_ratio\x12+.spaceone.api.inventory.v1.GetCoverageQuery\x1a\x17.google.protobuf.Struct\"6\x82\xd3\xe4\x93\x02\x30\x12./inventory/v1/savings-azure/get_coverage_ratiob\x06proto3')



_SAVINGSCOLLECTREQUEST = DESCRIPTOR.message_types_by_name['SavingsCollectRequest']
_SAVINGSSUMMARYREQUEST = DESCRIPTOR.message_types_by_name['SavingsSummaryRequest']
_GETCOVERAGEQUERY = DESCRIPTOR.message_types_by_name['GetCoverageQuery']
SavingsCollectRequest = _reflection.GeneratedProtocolMessageType('SavingsCollectRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSCOLLECTREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_azure_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsCollectRequest)
  })
_sym_db.RegisterMessage(SavingsCollectRequest)

SavingsSummaryRequest = _reflection.GeneratedProtocolMessageType('SavingsSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSSUMMARYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_azure_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsSummaryRequest)
  })
_sym_db.RegisterMessage(SavingsSummaryRequest)

GetCoverageQuery = _reflection.GeneratedProtocolMessageType('GetCoverageQuery', (_message.Message,), {
  'DESCRIPTOR' : _GETCOVERAGEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_azure_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetCoverageQuery)
  })
_sym_db.RegisterMessage(GetCoverageQuery)

_SAVINGSAZURE = DESCRIPTOR.services_by_name['SavingsAzure']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SAVINGSAZURE.methods_by_name['create_recommendation']._options = None
  _SAVINGSAZURE.methods_by_name['create_recommendation']._serialized_options = b'\202\323\344\223\0023\0221/inventory/v1/savings-azure/create_recommendation'
  _SAVINGSAZURE.methods_by_name['create_inventory']._options = None
  _SAVINGSAZURE.methods_by_name['create_inventory']._serialized_options = b'\202\323\344\223\002.\022,/inventory/v1/savings-azure/create_inventory'
  _SAVINGSAZURE.methods_by_name['create_summary']._options = None
  _SAVINGSAZURE.methods_by_name['create_summary']._serialized_options = b'\202\323\344\223\002,\022*/inventory/v1/savings-azure/create_summary'
  _SAVINGSAZURE.methods_by_name['get_coverage_ratio']._options = None
  _SAVINGSAZURE.methods_by_name['get_coverage_ratio']._serialized_options = b'\202\323\344\223\0020\022./inventory/v1/savings-azure/get_coverage_ratio'
  _SAVINGSCOLLECTREQUEST._serialized_start=199
  _SAVINGSCOLLECTREQUEST._serialized_end=283
  _SAVINGSSUMMARYREQUEST._serialized_start=285
  _SAVINGSSUMMARYREQUEST._serialized_end=407
  _GETCOVERAGEQUERY._serialized_start=410
  _GETCOVERAGEQUERY._serialized_end=581
  _SAVINGSAZURE._serialized_start=584
  _SAVINGSAZURE._serialized_end=1200
# @@protoc_insertion_point(module_scope)



#
#   Copyright 2020 The SpaceONE Authors.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


from setuptools import setup, find_packages

with open('../../VERSION', 'r') as f: 
    VERSION = f.read().strip()
    f.close()

setup(
    name='kt-ds-api-wadda',
    version=VERSION,
    description='',
    long_description='',
    url='',
    author='',
    author_email='',
    license='',
    packages=find_packages(),
    zip_safe=False,
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/unused_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.spaceone/api/inventory/v1/unused_service.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"B\n\x1b\x43ollectUnusedServiceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\"G\n\x17GetUnusedServiceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11unused_service_id\x18\x02 \x01(\t\"\x8b\x02\n\x12UnusedServiceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x13\n\x0bresource_id\x18\x06 \x01(\t\x12\x15\n\rresource_name\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x15\n\rinstance_type\x18\t \x01(\t\x12\x17\n\x0funused_resource\x18\n \x01(\t\x12\x13\n\x0bunused_type\x18\x0b \x01(\t\"\xe2\x03\n\x11UnusedServiceInfo\x12\x19\n\x11unused_service_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x13\n\x0bresource_id\x18\x06 \x01(\t\x12\x15\n\rresource_name\x18\x07 \x01(\t\x12\x33\n\x12\x63loud_service_info\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06region\x18\t \x01(\t\x12\x15\n\rinstance_type\x18\n \x01(\t\x12\x17\n\x0funused_resource\x18\x0b \x01(\t\x12%\n\x04\x63ost\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nsetting_id\x18\r \x01(\t\x12%\n\x04\x64\x61ta\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x0f \x01(\t\x12\x12\n\ndeleted_at\x18\x10 \x01(\t\x12\x13\n\x0b\x61nalyzed_at\x18\x11 \x01(\t\x12\x13\n\x0bunused_type\x18\x12 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x13 \x01(\t\"h\n\x12UnusedServicesInfo\x12=\n\x07results\x18\x01 \x03(\x0b\x32,.spaceone.api.inventory.v1.UnusedServiceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"a\n\x16UnusedServiceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xd6\x05\n\rUnusedService\x12\x88\x01\n\x07\x63ollect\x12\x36.spaceone.api.inventory.v1.CollectUnusedServiceRequest\x1a\x17.google.protobuf.Struct\",\x82\xd3\xe4\x93\x02&\"$/inventory/v1/unused-service/collect\x12\x91\x01\n\x03get\x12\x32.spaceone.api.inventory.v1.GetUnusedServiceRequest\x1a,.spaceone.api.inventory.v1.UnusedServiceInfo\"(\x82\xd3\xe4\x93\x02\"\" /inventory/v1/unused-service/get\x12\x90\x01\n\x04list\x12-.spaceone.api.inventory.v1.UnusedServiceQuery\x1a-.spaceone.api.inventory.v1.UnusedServicesInfo\"*\x82\xd3\xe4\x93\x02$\"\"/inventory/v1/unused-services/list\x12~\n\x04stat\x12\x31.spaceone.api.inventory.v1.UnusedServiceStatQuery\x1a\x17.google.protobuf.Struct\"*\x82\xd3\xe4\x93\x02$\"\"/inventory/v1/unused-services/stat\x12\x92\x01\n\x0eget_opt_report\x12\x31.spaceone.api.inventory.v1.UnusedServiceStatQuery\x1a\x17.google.protobuf.Struct\"4\x82\xd3\xe4\x93\x02.\",/inventory/v1/unused-services/get_opt_reportb\x06proto3')



_COLLECTUNUSEDSERVICEREQUEST = DESCRIPTOR.message_types_by_name['CollectUnusedServiceRequest']
_GETUNUSEDSERVICEREQUEST = DESCRIPTOR.message_types_by_name['GetUnusedServiceRequest']
_UNUSEDSERVICEQUERY = DESCRIPTOR.message_types_by_name['UnusedServiceQuery']
_UNUSEDSERVICEINFO = DESCRIPTOR.message_types_by_name['UnusedServiceInfo']
_UNUSEDSERVICESINFO = DESCRIPTOR.message_types_by_name['UnusedServicesInfo']
_UNUSEDSERVICESTATQUERY = DESCRIPTOR.message_types_by_name['UnusedServiceStatQuery']
CollectUnusedServiceRequest = _reflection.GeneratedProtocolMessageType('CollectUnusedServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTUNUSEDSERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectUnusedServiceRequest)
  })
_sym_db.RegisterMessage(CollectUnusedServiceRequest)

GetUnusedServiceRequest = _reflection.GeneratedProtocolMessageType('GetUnusedServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUNUSEDSERVICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetUnusedServiceRequest)
  })
_sym_db.RegisterMessage(GetUnusedServiceRequest)

UnusedServiceQuery = _reflection.GeneratedProtocolMessageType('UnusedServiceQuery', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceQuery)
  })
_sym_db.RegisterMessage(UnusedServiceQuery)

UnusedServiceInfo = _reflection.GeneratedProtocolMessageType('UnusedServiceInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICEINFO,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceInfo)
  })
_sym_db.RegisterMessage(UnusedServiceInfo)

UnusedServicesInfo = _reflection.GeneratedProtocolMessageType('UnusedServicesInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICESINFO,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServicesInfo)
  })
_sym_db.RegisterMessage(UnusedServicesInfo)

UnusedServiceStatQuery = _reflection.GeneratedProtocolMessageType('UnusedServiceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICESTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceStatQuery)
  })
_sym_db.RegisterMessage(UnusedServiceStatQuery)

_UNUSEDSERVICE = DESCRIPTOR.services_by_name['UnusedService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _UNUSEDSERVICE.methods_by_name['collect']._options = None
  _UNUSEDSERVICE.methods_by_name['collect']._serialized_options = b'\202\323\344\223\002&\"$/inventory/v1/unused-service/collect'
  _UNUSEDSERVICE.methods_by_name['get']._options = None
  _UNUSEDSERVICE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\"\" /inventory/v1/unused-service/get'
  _UNUSEDSERVICE.methods_by_name['list']._options = None
  _UNUSEDSERVICE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002$\"\"/inventory/v1/unused-services/list'
  _UNUSEDSERVICE.methods_by_name['stat']._options = None
  _UNUSEDSERVICE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002$\"\"/inventory/v1/unused-services/stat'
  _UNUSEDSERVICE.methods_by_name['get_opt_report']._options = None
  _UNUSEDSERVICE.methods_by_name['get_opt_report']._serialized_options = b'\202\323\344\223\002.\",/inventory/v1/unused-services/get_opt_report'
  _COLLECTUNUSEDSERVICEREQUEST._serialized_start=200
  _COLLECTUNUSEDSERVICEREQUEST._serialized_end=266
  _GETUNUSEDSERVICEREQUEST._serialized_start=268
  _GETUNUSEDSERVICEREQUEST._serialized_end=339
  _UNUSEDSERVICEQUERY._serialized_start=342
  _UNUSEDSERVICEQUERY._serialized_end=609
  _UNUSEDSERVICEINFO._serialized_start=612
  _UNUSEDSERVICEINFO._serialized_end=1094
  _UNUSEDSERVICESINFO._serialized_start=1096
  _UNUSEDSERVICESINFO._serialized_end=1200
  _UNUSEDSERVICESTATQUERY._serialized_start=1202
  _UNUSEDSERVICESTATQUERY._serialized_end=1299
  _UNUSEDSERVICE._serialized_start=1302
  _UNUSEDSERVICE._serialized_end=2028
# @@protoc_insertion_point(module_scope)
